Package: DataMetProcess
Type: Package
Title: Meteorological Data Processing
Version: 1.0.8
Authors@R: 
    c(
      person("Wagner Martins dos", "Santos",
              email = "wagnnerms97@gmail.com", role = c("aut", "cre"),
              comment = c(ORCID = "0000-0002-3584-1323")),
      person("Hoi Leong", "Lee",
              email = "", role = "aut",
              comment = ""),
      person("Edimir Xavier Leal", "Ferraz",
              email = "edimirferraz@outlook.com", role = "aut",
              comment = c(ORCID = "0000-0002-3151-8916")),
      person("Abelardo Antônio de Assunção", "Montenegro",
              email = "", role = "aut",
              comment = ""),
      person("Lady Daiane Costa de Sousa", "Martins",
              email = "teodosiod01@gmail.com", role = "aut",
              comment = c(ORCID = "0000-0002-0942-4673")),
      person("Alan Cézar", "Bezerra",
              email = "", role = "aut",
              comment = ""),
      person("Ênio Farias de França", "e Silva",
              email = "", role = "aut",
              comment = ""),
      person("Thieres George Freire", "da Silva",
              email = "", role = "aut",
              comment = c(ORCID = "0000-0002-8355-4935")),
      person("João L.M.P.", "de Lima",
              email = "", role = "aut",
              comment = ""),
      person("Xuguang", "Tang",
              email = "", role = "aut",
              comment = ""),
      person("Alexandre Maniçoba da Rosa Ferraz", "Jardim",
              email = "", role = "aut",
              comment = c(ORCID = "0000-0001-7094-3635"))
    )
Maintainer: Wagner Martins dos Santos <wagnnerms97@gmail.com>
Description: Set of tools aimed at processing meteorological data, converting hourly recorded data to daily, monthly and annual data.
License: GPL (>= 3)
Encoding: UTF-8
URL: https://github.com/wagnnerms97/DataMetProcess
BugReports: https://github.com/wagnnerms97/DataMetProcess/issues
Depends: R (>= 4.1)
RoxygenNote: 7.3.3
Imports: dplyr, tidyr, lubridate, rlang, utils, base, shiny, stringr
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-01-19 21:52:05 UTC; wagne
Author: Wagner Martins dos Santos [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3584-1323>),
  Hoi Leong Lee [aut],
  Edimir Xavier Leal Ferraz [aut] (ORCID:
    <https://orcid.org/0000-0002-3151-8916>),
  Abelardo Antônio de Assunção Montenegro [aut],
  Lady Daiane Costa de Sousa Martins [aut] (ORCID:
    <https://orcid.org/0000-0002-0942-4673>),
  Alan Cézar Bezerra [aut],
  Ênio Farias de França e Silva [aut],
  Thieres George Freire da Silva [aut] (ORCID:
    <https://orcid.org/0000-0002-8355-4935>),
  João L.M.P. de Lima [aut],
  Xuguang Tang [aut],
  Alexandre Maniçoba da Rosa Ferraz Jardim [aut] (ORCID:
    <https://orcid.org/0000-0001-7094-3635>)
Repository: CRAN
Date/Publication: 2026-01-20 08:30:14 UTC
Built: R 4.6.0; ; 2026-04-29 15:05:17 UTC; unix
